==> auto-ui-2.1.28.tgz: package/es/at-calendar/index.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import cn from 'classnames';
import * as React from 'react';
import { dateFormat, offsetDays } from '../__utils/transfer';
import Button from '../button';
import Layout from '../layout';
import Popup from '../popup';
import TimePicker from '../time-picker';
import Controller from './controller';
import './style.scss';
var AtCalendar = /** @class */ (function (_super) {
    __extends(AtCalendar, _super);
    function AtCalendar() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AtCalendar.prototype.render = function () {
        return (React.createElement(Layout, { className: "at-calendar" },
            this.renderHeader(),
            this.renderBody(),
            this.renderFooter(),
            this.renderTimePicker()));
    };
    // 页头
    AtCalendar.prototype.renderHeader = function () {
        var d1 = this.state.chooseRange[0];
        var d2 = this.state.chooseRange[1];
        var t1 = this.state.timePickerTimes[0];
        var t2 = this.state.timePickerTimes[1];
        return (React.createElement(Layout.Header, { className: "header", borderType: "border", onCloseClick: this.props.onClose, title: this.props.title, addonAfter: !this.props.readonly && (React.createElement("a", { className: "clear", onClick: this.clearChooseRange }, "\u6E05\u7A7A")), addonBottom: React.createElement(React.Fragment, null,
                !this.props.readonly && (React.createElement("div", { className: "time-range" },
                    React.createElement("div", { className: cn('date', 'from', { active: !!d1 }) },
                        React.createElement("h6", null, d1 ? dateFormat(d1, 'M月d日 周wk') : '取车时间'),
                        React.createElement("p", null, t1 ? dateFormat(t1, 'hh:mm') : '请设置')),
                    React.createElement("div", { className: cn('date', 'to', { active: !!d2 }) },
                        React.createElement("h6", null, d2 ? dateFormat(d2, 'M月d日 周wk') : '还车时间'),
                        React.createElement("p", null, t2 ? dateFormat(t2, 'hh:mm') : '请设置')))),
                React.createElement("ul", { className: "weeks" },
                    React.createElement("li", null, "\u4E00"),
                    React.createElement("li", null, "\u4E8C"),
                    React.createElement("li", null, "\u4E09"),
                    React.createElement("li", null, "\u56DB"),
                    React.createElement("li", null, "\u4E94"),
                    React.createElement("li", null, "\u516D"),
                    React.createElement("li", null, "\u65E5"))) }));
    };
    // 主体
    AtCalendar.prototype.renderBody = function () {
        var _this = this;
        return (React.createElement(Layout.Body, { className: "body", id: "x-calendar-body" }, this.getMonthList().map(function (month) {
            return _this.renderMonth(month);
        })));
    };
    // 月
    AtCalendar.prototype.renderMonth = function (month) {
        var _this = this;
        var y = month.getFullYear();
        var m = month.getMonth();
        var w = month.getDay() - 1;
        if (w === -1) {
            w = 6;
        }
        var space = (function () {
            var arr = [];
            for (var i = 0; i < w; i++) {
                arr.push('');
            }
            return arr;
        })();
        var count = new Date(y, m + 1, 0).getDate();
        var list = [];
        for (var i = 0; i < count; i++) {
            list.push(new Date(y, m, i + 1));
        }
        return (React.createElement("div", { className: "month", key: month.valueOf() },
            React.createElement("h2", { className: "month-title" }, m + 1 + "\u6708"),
            React.createElement("div", { className: "list" },
                space.map(function (_, i) { return (React.createElement("span", { className: "month-day empty", key: i })); }),
                list.map(function (date) { return _this.renderMonthDay(date); }))));
    };
    // 月份的每一天
    AtCalendar.prototype.renderMonthDay = function (date) {
        var _this = this;
        var key = date.valueOf();
        var data = this.props.data && this.props.data[key] ? this.props.data[key] : { disabled: 'DISABLED' };
        var isDisabledBefore = this.props.disabledBefore ? this.props.disabledBefore > date : false;
        if (data.disabled === 'DISABLED') {
            isDisabledBefore = true;
        }
        var readonly = this.props.readonly;
        var wkname = ['sun', 'mon', 'tues', 'wed', 'thur', 'fri', 'sat'];
        var isBtween = this.isBtweenChooseRange(date);
        var css = cn('month-day', wkname[date.getDay()], {
            active: !readonly && isBtween,
            'active-first': !readonly && this.state.chooseRange[0] && this.state.chooseRange[0].valueOf() === key,
            'active-end': !readonly && this.state.chooseRange[1] && this.state.chooseRange[1].valueOf() === key,
            disabled: isDisabledBefore,
            'is-holiday': data.isHoliday,
            'disabled-all': !isDisabledBefore && data.disabled === 'ALL',
            'disabled-part': !isDisabledBefore && data.disabled === 'PART',
        });
        var onClick = function () {
            if ((isDisabledBefore || readonly || data.disabled) && !isBtween) {
                return;
            }
            _this.onDayClick(date, data);
        };
        return (React.createElement("div", { className: css, key: key, onClick: onClick },
            React.createElement("p", null,
                React.createElement("em", null, date.getDate())),
            data.price && React.createElement("span", null,
                "\uFFE5",
                data.price)));
    };
    // 页脚
    AtCalendar.prototype.renderFooter = function () {
        var min = this.props.minHours || 0;
        var times = this.state.timePickerTimes;
        var chooseOk = times[0] !== null && times[1] !== null;
        var tips = '请选择租期';
        if (min >= 24) {
            tips = Math.round((min / 24) * 100) / 100 + "\u5929\u8D77\u79DF";
        }
        else if (min > 0) {
            tips = min + "\u5C0F\u65F6\u8D77\u79DF";
        }
        return (React.createElement(Layout.Footer, { className: "footer" },
            React.createElement("div", { className: "tips" },
                React.createElement("p", null,
                    React.createElement("i", null),
                    "\u5168\u5929\u53EF\u79DF"),
                React.createElement("p", null,
                    React.createElement("i", { className: "part" }),
                    "\u90E8\u5206\u65F6\u6BB5\u53EF\u79DF")),
            !this.props.readonly && (React.createElement("div", { className: "bottom" },
                chooseOk ? (React.createElement("p", null,
                    "\u5171\u8BA1",
                    React.createElement("strong", null, offsetDays(times[0], times[1])))) : (React.createElement("p", null, tips)),
                React.createElement(Button, { className: "submit", onClick: this.onSubmit }, "\u786E\u5B9A")))));
    };
    // 时间选择器
    AtCalendar.prototype.renderTimePicker = function () {
        var def = new Date(2000, 1, 1);
        if (this.state.chooseType === 'rent' && this.state.chooseRange[0]) {
            def = this.state.chooseRange[0];
        }
        else if (this.state.chooseType === 'revert' && this.state.chooseRange[1]) {
            def = this.state.chooseRange[1];
        }
        if (this.state.chooseType === 'rent' &&
            this.state.preChooseRange[0] &&
            def.valueOf() === this.state.preChooseRange[0].valueOf()) {
            def = this.state.preTimePickerTimes[0];
        }
        else if (this.state.chooseType === 'revert' &&
            this.state.preChooseRange[1] &&
            def.valueOf() === this.state.preChooseRange[1].valueOf()) {
            def = this.state.preTimePickerTimes[1];
        }
        return (React.createElement(Popup, { visible: this.state.timePickerVisible, noPadding: true, className: "at-calendar__time-picker", onMaskClick: this.timePickerCancel, height: "4.9rem" },
            React.createElement("header", { className: "header" },
                React.createElement("a", { className: "cancel", onClick: this.timePickerCancel }, "\u53D6\u6D88"),
                React.createElement("h2", null,
                    "\u8BF7\u9009\u62E9",
                    this.state.chooseType === 'rent' ? '取' : '还',
                    "\u8F66\u65F6\u95F4"),
                React.createElement("a", { onClick: this.timePickerNext }, "\u4E0B\u4E00\u6B65")),
            React.createElement(TimePicker, { data: [this.state.timePickerData], tips: this.state.timePickerTips, format: ['MM月dd日 周wk', 'h点', 'm分'], interval: 15, defaultDay: def, onChange: this.onTimeChange, ref: this.timePickerRef })));
    };
    return AtCalendar;
}(Controller));
export default AtCalendar;

==> auto-ui-2.1.54.tgz: package/es/at-calendar/index.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import cn from 'classnames';
import * as React from 'react';
import { dateFormat, offsetDays } from '../__utils/transfer';
import Button from '../button';
import Layout from '../layout';
import Popup from '../popup';
import TimePicker from '../time-picker';
import Controller from './controller';
import './style.scss';
var AtCalendar = /** @class */ (function (_super) {
    __extends(AtCalendar, _super);
    function AtCalendar() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AtCalendar.prototype.render = function () {
        return (React.createElement(Layout, { className: "at-calendar" },
            this.renderHeader(),
            this.renderBody(),
            this.renderFooter(),
            this.renderTimePicker()));
    };
    // 页头
    AtCalendar.prototype.renderHeader = function () {
        var d1 = this.state.chooseRange[0];
        var d2 = this.state.chooseRange[1];
        var t1 = this.state.timePickerTimes[0];
        var t2 = this.state.timePickerTimes[1];
        return (React.createElement(Layout.Header, { className: "header", borderType: "border", onCloseClick: this.props.onClose, title: this.props.title, addonAfter: !this.props.readonly && (React.createElement("a", { className: "clear", onClick: this.clearChooseRange }, "\u6E05\u7A7A")), addonBottom: React.createElement(React.Fragment, null,
                !this.props.readonly && (React.createElement("div", { className: "time-range" },
                    React.createElement("div", { className: cn('date', 'from', { active: !!d1 }) },
                        React.createElement("h6", null, d1 ? dateFormat(d1, 'M月d日 周wk') : '取车时间'),
                        React.createElement("p", null, t1 ? dateFormat(t1, 'hh:mm') : '请设置')),
                    React.createElement("div", { className: cn('date', 'to', { active: !!d2 }) },
                        React.createElement("h6", null, d2 ? dateFormat(d2, 'M月d日 周wk') : '还车时间'),
                        React.createElement("p", null, t2 ? dateFormat(t2, 'hh:mm') : '请设置')))),
                React.createElement("ul", { className: "weeks" },
                    React.createElement("li", null, "\u4E00"),
                    React.createElement("li", null, "\u4E8C"),
                    React.createElement("li", null, "\u4E09"),
                    React.createElement("li", null, "\u56DB"),
                    React.createElement("li", null, "\u4E94"),
                    React.createElement("li", null, "\u516D"),
                    React.createElement("li", null, "\u65E5"))) }));
    };
    // 主体
    AtCalendar.prototype.renderBody = function () {
        var _this = this;
        return (React.createElement(Layout.Body, { className: "body", id: "x-calendar-body" }, this.getMonthList().map(function (month) {
            return _this.renderMonth(month);
        })));
    };
    // 月
    AtCalendar.prototype.renderMonth = function (month) {
        var _this = this;
        var y = month.getFullYear();
        var m = month.getMonth();
        var w = month.getDay() - 1;
        if (w === -1) {
            w = 6;
        }
        var space = (function () {
            var arr = [];
            for (var i = 0; i < w; i++) {
                arr.push('');
            }
            return arr;
        })();
        var count = new Date(y, m + 1, 0).getDate();
        var list = [];
        for (var i = 0; i < count; i++) {
            list.push(new Date(y, m, i + 1));
        }
        return (React.createElement("div", { className: "month", key: month.valueOf() },
            React.createElement("h2", { className: "month-title" }, m + 1 + "\u6708"),
            React.createElement("div", { className: "list" },
                space.map(function (_, i) { return (React.createElement("span", { className: "month-day empty", key: i })); }),
                list.map(function (date) { return _this.renderMonthDay(date); }))));
    };
    // 月份的每一天
    AtCalendar.prototype.renderMonthDay = function (date) {
        var _this = this;
        var key = date.valueOf();
        var data = this.props.data && this.props.data[key] ? this.props.data[key] : { disabled: 'DISABLED' };
        var isDisabledBefore = this.props.disabledBefore ? this.props.disabledBefore > date : false;
        if (data.disabled === 'DISABLED') {
            isDisabledBefore = true;
        }
        var readonly = this.props.readonly;
        var wkname = ['sun', 'mon', 'tues', 'wed', 'thur', 'fri', 'sat'];
        var isBtween = this.isBtweenChooseRange(date);
        var css = cn('month-day', wkname[date.getDay()], {
            active: !readonly && isBtween,
            'active-first': !readonly && this.state.chooseRange[0] && this.state.chooseRange[0].valueOf() === key,
            'active-end': !readonly && this.state.chooseRange[1] && this.state.chooseRange[1].valueOf() === key,
            disabled: isDisabledBefore,
            'is-holiday': data.isHoliday,
            'disabled-all': !isDisabledBefore && data.disabled === 'ALL',
            'disabled-part': !isDisabledBefore && data.disabled === 'PART',
        });
        var onClick = function () {
            if ((isDisabledBefore || readonly || data.disabled) && !isBtween) {
                return;
            }
            _this.onDayClick(date, data);
        };
        return (React.createElement("div", { className: css, key: key, onClick: onClick },
            React.createElement("p", null,
                React.createElement("em", null, date.getDate()),
                data.badge ? React.createElement("i", null, data.badge) : null),
            data.price && React.createElement("span", null,
                "\uFFE5",
                data.price)));
    };
    // 页脚
    AtCalendar.prototype.renderFooter = function () {
        var min = this.props.minHours || 0;
        var times = this.state.timePickerTimes;
        var chooseOk = times[0] !== null && times[1] !== null;
        var tips = '请选择租期';
        if (min >= 24) {
            tips = Math.round((min / 24) * 100) / 100 + "\u5929\u8D77\u79DF";
        }
        else if (min > 0) {
            tips = min + "\u5C0F\u65F6\u8D77\u79DF";
        }
        return (React.createElement(Layout.Footer, { className: "footer" },
            React.createElement("div", { className: "tips" },
                React.createElement("p", null,
                    React.createElement("i", null),
                    "\u5168\u5929\u53EF\u79DF"),
                React.createElement("p", null,
                    React.createElement("i", { className: "part" }),
                    "\u90E8\u5206\u65F6\u6BB5\u53EF\u79DF")),
            !this.props.readonly && (React.createElement("div", { className: "bottom" },
                chooseOk ? (React.createElement("p", null,
                    "\u5171\u8BA1",
                    React.createElement("strong", null, offsetDays(times[0], times[1])))) : (React.createElement("p", null, tips)),
                React.createElement(Button, { className: "submit", onClick: this.onSubmit }, "\u786E\u5B9A")))));
    };
    // 时间选择器
    AtCalendar.prototype.renderTimePicker = function () {
        var def = new Date(2000, 1, 1);
        if (this.state.chooseType === 'rent' && this.state.chooseRange[0]) {
            def = this.state.chooseRange[0];
        }
        else if (this.state.chooseType === 'revert' && this.state.chooseRange[1]) {
            def = this.state.chooseRange[1];
        }
        if (this.state.chooseType === 'rent' &&
            this.state.preChooseRange[0] &&
            def.valueOf() === this.state.preChooseRange[0].valueOf()) {
            def = this.state.preTimePickerTimes[0];
        }
        else if (this.state.chooseType === 'revert' &&
            this.state.preChooseRange[1] &&
            def.valueOf() === this.state.preChooseRange[1].valueOf()) {
            def = this.state.preTimePickerTimes[1];
        }
        return (React.createElement(Popup, { visible: this.state.timePickerVisible, noPadding: true, className: "at-calendar__time-picker", onMaskClick: this.timePickerCancel, height: "4.9rem" },
            React.createElement("header", { className: "header" },
                React.createElement("a", { className: "cancel", onClick: this.timePickerCancel }, "\u53D6\u6D88"),
                React.createElement("h2", null,
                    "\u8BF7\u9009\u62E9",
                    this.state.chooseType === 'rent' ? '取' : '还',
                    "\u8F66\u65F6\u95F4"),
                React.createElement("a", { onClick: this.timePickerNext }, "\u4E0B\u4E00\u6B65")),
            React.createElement(TimePicker, { data: [this.state.timePickerData], tips: this.state.timePickerTips, format: ['MM月dd日 周wk', 'h点', 'm分'], interval: 15, defaultDay: def, onChange: this.onTimeChange, ref: this.timePickerRef })));
    };
    return AtCalendar;
}(Controller));
export default AtCalendar;
